#
# spec file for package python-rapidfuzz
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-rapidfuzz
Version:        2.13.7
Release:        3.1
Summary:        Rapid fuzzy string matching
License:        MIT
URL:            https://github.com/maxbachmann/RapidFuzz
Source:         https://files.pythonhosted.org/packages/source/r/rapidfuzz/rapidfuzz-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module PyInstaller}
BuildRequires:  %{python_module devel >= 3.7}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scikit-build}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  ninja
BuildRequires:  python-rpm-macros
Suggests:       python-numpy
%if 0%{?suse_version} < 1550
BuildRequires:  gcc11-c++ >= 8
%else
BuildRequires:  gcc-c++
%endif
%python_subpackages

%description
RapidFuzz is a fast string matching library for Python and C++, which is using the string similarity calculations from FuzzyWuzzy.

%prep
%autosetup -p1 -n rapidfuzz-%{version}

%build
%if 0%{?suse_version} < 1550
export CXX=g++-11 CC=gcc-11
%endif
export CFLAGS="%{optflags} -fno-strict-aliasing"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
# remove devel file
%python_expand find %{buildroot} -type f -name "rapidfuzz.h" -delete -print

%check
# tests are a bit unstable
%ifarch x86_64
export skip_tests="not (hypothesis and test_cdist)"
%else
%ifarch %ix86
export skip_tests="not (hypothesis and test_jaro_winkler_word)"
%else
export skip_tests=""
%endif
%endif
%pytest_arch -k "$skip_tests"

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitearch}/rapidfuzz
%{python_sitearch}/rapidfuzz-%{version}.dist-info/

%changelog
* Wed May 31 2023 Johannes Kastl <kastl@b1-systems.de>
- do not use glob for dist-info directory name
* Mon May  8 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Mon Feb 27 2023 Matej Cepl <mcepl@suse.com>
- Clean up the SPEC file.
* Fri Feb 24 2023 Torsten Gruner <simmphonie@opensuse.org>
- update to version 2.13.7
  * fix function signature of get_requires_for_build_wheel
* Sat Dec 17 2022 Torsten Gruner <simmphonie@opensuse.org>
- update to version 2.13.6
  * Changed
    + reformat changelog as restructured text to get rig of m2r2 dependency
- version 2.13.5
  * Added
    + added docs to sdist
  * Fixed
    + fix two cases of undefined behavior in process.cdist
- version 2.13.4
  * Changed
    + handle float("nan") similar to None for query / choice, since this is
    common for non-existent data in tools like numpy
  * Fixed
    + fix handling on None/float("nan") in process.distance
    + use absolute imports inside tests
- version 2.13.3
  * Fixed
    + improve handling of functions wrapped using functools.wraps
    + fix broken fallback to Python implementation when the a ImportError occurs on import.
    This can e.g. occur when the binary has a dependency on libatomic, but it
    is unavailable on the system
    + define CMAKE_C_COMPILER_AR/CMAKE_CXX_COMPILER_AR/CMAKE_C_COMPILER_RANLIB/CMAKE_CXX_COMPILER_RANLIB
    if they are not defined yet
* Thu Oct 27 2022 Markéta Machová <mmachova@suse.com>
- initial packaging (v2.13.2), dependency of weblate
